@@ -17,8 +17,7 @@ RES_FULL_HD = (1920, 1080)
 PAR_HD = 1
 
 
-def SAR(RES):
-    # type: (Tuple[int, int], ) -> float
+def SAR(RES: Tuple[int, int]) -> float:
 
     x, y = RES
     return x / y
