@@ -1,21 +1,18 @@
 from __future__ import generator_stop
 
 import logging
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Iterator, Union
 
 import cv2
 import numpy as np
 
 if TYPE_CHECKING:
-    from typing import Iterator, Union
-
     import wx  # noqa: F401
 
 logger = logging.getLogger(__name__)
 
 
-def wx_to_cv_image(wximage):
-    # type (wx.Image, ) -> np.ndarray
+def wx_to_cv_image(wximage: "wx.Image") -> np.ndarray:
 
     buf = wximage.GetDataBuffer()
     arr = np.asarray(buf, dtype=np.uint8)
@@ -23,14 +20,12 @@ def wx_to_cv_image(wximage):
     return np.reshape(arr, (wximage.Height, wximage.Width, 3))[:, :, ::-1]  # RGB => BGR
 
 
-def grayscale(cvimg):
-    # type: (np.ndarray, ) -> np.ndarray
+def grayscale(cvimg: np.ndarray) -> np.ndarray:
 
     return cv2.cvtColor(cvimg, cv2.COLOR_RGB2GRAY)
 
 
-def iter_video(input=0, show=False):
-    # type: (Union[str, int], bool) -> Iterator[np.ndarray]
+def iter_video(input: Union[str, int] = 0, show: bool = False) -> Iterator[np.ndarray]:
 
     cap = cv2.VideoCapture(input)
     logger.debug("Reading video using %s backend", cap.getBackendName())
