@@ -14,19 +14,16 @@ class GenericLabelEncoder:
 
     """Encodes all hashable objects to integers"""
 
-    def __init__(self):
-        # type: () -> None
+    def __init__(self) -> None:
 
         self.reset()
 
-    def reset(self):
-        # type: () -> None
+    def reset(self) -> None:
 
-        self.object2idx = {}  # type: Dict[Hashable, int]
-        self.idx2object = []  # type: List[Hashable]
+        self.object2idx: Dict[Hashable, int] = {}
+        self.idx2object: List[Hashable] = []
 
-    def encode(self, obj):
-        # type: (Hashable, ) -> int
+    def encode(self, obj: Hashable) -> int:
 
         """Encode a hashable `obj` to an integer."""
 
@@ -37,14 +34,12 @@ class GenericLabelEncoder:
 
         return idx
 
-    def encode_batch(self, objs):
-        # type: (Iterable[Hashable], ) -> Iterator[int]
+    def encode_batch(self, objs: Iterable[Hashable]) -> Iterator[int]:
 
         for obj in objs:
             yield self.encode(obj)
 
-    def decode(self, idx):
-        # type: (int, ) -> Hashable
+    def decode(self, idx: int) -> Hashable:
 
         """Decode an integer `idx` to the previously encoded object.
         Raises IndexError if the index is out of range.
@@ -52,14 +47,12 @@ class GenericLabelEncoder:
 
         return self.idx2object[idx]
 
-    def decode_batch(self, indices):
-        # type: (Iterable[int], ) -> Iterator[Hashable]
+    def decode_batch(self, indices: Iterable[int]) -> Iterator[Hashable]:
 
         for idx in indices:
             yield self.decode(idx)
 
-    def __len__(self):
-        # type: () -> int
+    def __len__(self) -> int:
 
         assert len(self.object2idx) == len(self.idx2object)
         return len(self.idx2object)
@@ -81,18 +74,16 @@ class BatchLabelEncoder(Generic[T]):
         }[tokenizer]
         self.reset()
 
-    def reset(self):
-        # type: () -> None
+    def reset(self) -> None:
 
         """Initializes all mappings with empty containers."""
 
-        self.token2idx = {}  # type: Dict[T, int]
+        self.token2idx: Dict[T, int] = {}
 
-        self.idx2count = []  # type: Union[List[int], np.ndarray]
-        self.idx2token = []  # type: Union[List[T], np.ndarray]
+        self.idx2count: Union[List[int], np.ndarray] = []
+        self.idx2token: Union[List[T], np.ndarray] = []
 
-    def finalize(self, vocab_size):
-        # type: (int, ) -> None
+    def finalize(self, vocab_size: int) -> None:
 
         """This only keeps the most frequent `vocab_size` words in the vocabulary.
         This will change the assigned indices, so if `transform` was used before `finalize`,
@@ -108,8 +99,7 @@ class BatchLabelEncoder(Generic[T]):
 
         self.token2idx = {token: i for i, token in enumerate(self.idx2token)}
 
-    def partial_fit_single(self, token):
-        # type: (T, ) -> int
+    def partial_fit_single(self, token: T) -> int:
 
         vocab_size = self.num_labels
         idx = self.token2idx.setdefault(token, vocab_size)
@@ -121,42 +111,35 @@ class BatchLabelEncoder(Generic[T]):
 
         return idx
 
-    def partial_fit(self, sentence):
-        # type: (str, ) -> None
+    def partial_fit(self, sentence: str) -> None:
 
         for token in self.tokenizer(sentence):
             self.partial_fit_single(token)
 
-    def partial_fit_batch(self, sentences):
-        # type: (Iterable[str], ) -> None
+    def partial_fit_batch(self, sentences: Iterable[str]) -> None:
 
         for sentence in sentences:
             self.partial_fit(sentence)
 
-    def fit_single(self, token):
-        # type: (T, ) -> None
+    def fit_single(self, token: T) -> None:
 
         self.partial_fit_single(token)
 
-    def fit(self, sentence):
-        # type: (str, ) -> None
+    def fit(self, sentence: str) -> None:
 
         self.partial_fit(sentence)
 
-    def fit_batch(self, sentences):
-        # type: (Iterable[str], ) -> None
+    def fit_batch(self, sentences: Iterable[str]) -> None:
 
         self.partial_fit_batch(sentences)
 
-    def transform_single(self, token):
-        # type: (T, ) -> int
+    def transform_single(self, token: T) -> int:
 
         """Unknown labels are skipped."""
 
         return self.token2idx[token]
 
-    def transform(self, sentence, ignore=True):
-        # type: (str, bool) -> Iterator[int]
+    def transform(self, sentence: str, ignore: bool = True) -> Iterator[int]:
 
         for token in self.tokenizer(sentence):
             try:
@@ -167,51 +150,43 @@ class BatchLabelEncoder(Generic[T]):
                 else:
                     raise
 
-    def transform_batch(self, sentences, ignore=True):
-        # type: (Iterable[str], bool) -> Iterator[List[int]]
+    def transform_batch(self, sentences: Iterable[str], ignore: bool = True) -> Iterator[List[int]]:
 
         """Unknown labels are skipped."""
 
         for sentence in sentences:
             yield list(self.transform(sentence, ignore))
 
-    def fit_transform_single(self, token):
-        # type: (T, ) -> int
+    def fit_transform_single(self, token: T) -> int:
 
         return self.partial_fit_single(token)
 
-    def fit_transform(self, sentences):
-        # type: (str, ) -> Iterator[int]
+    def fit_transform(self, sentences: str) -> Iterator[int]:
 
         self.partial_fit(sentences)
         return self.transform(sentences)
 
-    def fit_transform_batch(self, sentences):
-        # type: (Iterable[str], ) -> Iterator[List[int]]
+    def fit_transform_batch(self, sentences: Iterable[str]) -> Iterator[List[int]]:
 
         self.partial_fit_batch(sentences)
         return self.transform_batch(sentences)
 
-    def inverse_transform_single(self, idx):
-        # type: (int, ) -> T
+    def inverse_transform_single(self, idx: int) -> T:
 
         return self.idx2token[idx]
 
-    def inverse_transform(self, indices):
-        # type: (Iterable[int], ) -> Iterator[T]
+    def inverse_transform(self, indices: Iterable[int]) -> Iterator[T]:
 
         for idx in indices:
             yield self.inverse_transform_single(idx)
 
-    def inverse_transform_batch(self, list_of_indices):
-        # type: (Iterable[Iterable[int]], ) -> Iterator[List[T]]
+    def inverse_transform_batch(self, list_of_indices: Iterable[Iterable[int]]) -> Iterator[List[T]]:
 
         for indices in list_of_indices:
             yield list(self.inverse_transform(indices))
 
     @property
-    def num_labels(self):
-        # type: () -> int
+    def num_labels(self) -> int:
 
         assert len(self.token2idx) == len(self.idx2count) == len(self.idx2token)
         return len(self.idx2token)
