@@ -17,12 +17,12 @@ from os import DirEntry, PathLike, fspath
 from pathlib import Path
 from typing import Any, Callable, Iterable, Iterator, List, Optional, Set, Tuple, Union
 
-from ._files import BaseDirEntry, MyDirEntryT, entrysuffix
+from ._files import BaseDirEntry, MyDirEntryT, entrysuffix, to_dos_device_path
 from .datetime import datetime_from_utc_timestamp
 from .file import FILE_IO_BUFFER_SIZE, equal_files, iterfilelike
 from .iter import is_empty
 from .ops import logical_implication
-from .os import _not_available, islink, uncabspath
+from .os import _not_available, islink
 
 PathType = Union[str, PathLike]
 EntryType = Union[Path, DirEntry]
@@ -211,6 +211,17 @@ class MyDirEntry(BaseDirEntry):
         self._relpath = path
 
 
+if platform.system() == "Windows":
+
+    def long_path_support(path: str) -> str:
+        return to_dos_device_path(os.path.abspath(path))
+
+else:
+
+    def long_path_support(path: str) -> str:
+        return path
+
+
 def mdatetime(path: PathType, aslocal: bool = False) -> datetime:
 
     """Returns the last modified date of `path`
@@ -315,11 +326,31 @@ def scandir_error_ignore(entry: DirEntry, exception) -> None:
     pass
 
 
+def _is_loop(rootentry: DirEntry, entry: DirEntry, is_link: bool, loops: Optional[Set[str]]) -> bool:
+
+    if loops is not None:
+        if is_link:
+            _path = os.readlink(entry)
+
+            if not os.path.isabs(_path):  # symlinks might be relative
+                _path = os.path.join(rootentry.path, _path)
+        else:
+            _path = entry.path
+
+        if _path in loops:
+            return True
+        else:
+            loops.add(_path)
+
+    return False
+
+
 def _scandir_rec_skippable(
     rootentry: DirEntry,
     files: bool = True,
     others: bool = False,
     follow_symlinks: bool = True,
+    prevent_loops_set: Optional[Set[str]] = None,
     errorfunc: Callable[[DirEntry, Exception], None] = scandir_error_raise,
 ) -> Iterator[MyDirEntry]:
 
@@ -329,12 +360,20 @@ def _scandir_rec_skippable(
                 if files and entry.is_file(follow_symlinks=follow_symlinks):
                     yield MyDirEntry(entry)
                 elif entry.is_dir(follow_symlinks=follow_symlinks):
-                    if not follow_symlinks and islink(entry):  # must be a windows junction
+
+                    if not follow_symlinks or prevent_loops_set is not None:
+                        is_link = islink(entry)
+                    if (
+                        not follow_symlinks and is_link
+                    ):  # must be a windows junction since `entry.is_symlink()` returns `False` for junctions
                         continue
+
                     se = MyDirEntry(entry)
                     yield se
-                    if se.follow:
-                        for e in _scandir_rec_skippable(entry, files, others, follow_symlinks, errorfunc):
+                    if se.follow and not _is_loop(rootentry, entry, is_link, prevent_loops_set):
+                        for e in _scandir_rec_skippable(
+                            entry, files, others, follow_symlinks, prevent_loops_set, errorfunc
+                        ):
                             yield e
                 else:
                     if others:
@@ -350,23 +389,33 @@ def _scandir_rec(
     others: bool = False,
     rec: bool = True,
     follow_symlinks: bool = True,
+    prevent_loops_set: Optional[Set[str]] = None,
     errorfunc: Callable[[DirEntry, Exception], None] = scandir_error_raise,
 ) -> Iterator[DirEntry]:
 
+    is_link: Optional[bool] = None
+
     try:
         with os.scandir(rootentry.path) as it:
             for entry in it:
                 if files and entry.is_file(follow_symlinks=follow_symlinks):
                     yield entry
                 elif entry.is_dir(follow_symlinks=follow_symlinks):
-                    if not follow_symlinks and islink(
-                        entry
-                    ):  # must be a windows junction. entry.is_symlink() doesn't support junctions
+
+                    if not follow_symlinks or prevent_loops_set is not None:
+                        is_link = islink(entry)
+                    if (
+                        not follow_symlinks and is_link
+                    ):  # must be a windows junction since `entry.is_symlink()` returns `False` for junctions
                         continue
+
                     if dirs:
                         yield entry
-                    if rec:
-                        for e in _scandir_rec(entry, files, dirs, others, rec, follow_symlinks, errorfunc):
+
+                    if rec and not _is_loop(rootentry, entry, is_link, prevent_loops_set):
+                        for e in _scandir_rec(
+                            entry, files, dirs, others, rec, follow_symlinks, prevent_loops_set, errorfunc
+                        ):
                             yield e
                 else:
                     if others:
@@ -375,6 +424,10 @@ def _scandir_rec(
         errorfunc(rootentry, e)
 
 
+def _get_entry_stub(path: str) -> DirEntry:
+    return DirEntryStub(os.path.basename(path), long_path_support(path))
+
+
 def scandir_rec(
     path: PathType,
     files: bool = True,
@@ -382,28 +435,51 @@ def scandir_rec(
     others: bool = False,
     rec: bool = True,
     follow_symlinks: bool = True,
+    prevent_loops: bool = True,
     relative: bool = False,
     allow_skip: bool = False,
     errorfunc: Callable[[MyDirEntryT, Exception], None] = scandir_error_log,
 ) -> Iterator[MyDirEntryT]:
 
+    r"""Variant of `os.scandir()` which recurses into subfolders.
+    `path`: Relative or absolute filesystem path. On Windows this path is converted to a absolute device path <\\?\X:\path\file.exe> to support long paths.
+    `files`: Yield files.
+    `dirs`: Yield directories.
+    `others`: Yield other entries which are neither files nor directories.
+    `rec`: Recurse into subfolders.
+    `follow_symlinks`: Follow symbolic links or directory junctions.
+    `prevent_loops`: Directory links can lead to infinite recursion.
+        If this is True, visited paths will be remembered and only followed once.
+        Directories which are links will always be returned, but their contents only when they are encountered first.
+        Symbolic links to files are always returned, which may lead to file duplicates, but not to loops.
+        If `follow_symlinks` is False, this argument has no effect.
+    `relative`: Yield `MyDirEntry` objects which expose a `relpath` attribute which contains the path as relativ to `path`
+    `allow_skip`: Yield `MyDirEntry` objects which expose a `follow` attribute. If this is set to False for directories,
+        they will not be followed.
+    `errorfunc`: A callback function to handle errors. By default errors are logged as exceptions and ignored.
+    """
+
     if not logical_implication(allow_skip, dirs and rec):
         raise ValueError("allow_skip implies dirs and rec")
 
     if isinstance(path, PathLike):
         path = fspath(path)
 
-    entry = DirEntryStub(os.path.basename(path), uncabspath(path))  # for python 2 compat. and long filename support
+    if not follow_symlinks or not rec:
+        prevent_loops = False
+
+    entry = _get_entry_stub(path)
+    prevent_loops_set: Optional[Set[str]] = set() if prevent_loops else None
 
     if not allow_skip:
-        it = _scandir_rec(entry, files, dirs, others, rec, follow_symlinks, errorfunc)
+        it = _scandir_rec(entry, files, dirs, others, rec, follow_symlinks, prevent_loops_set, errorfunc)
     else:
-        it = _scandir_rec_skippable(entry, files, others, follow_symlinks, errorfunc)
+        it = _scandir_rec_skippable(entry, files, others, follow_symlinks, prevent_loops_set, errorfunc)
 
     if not relative:
         return it
     else:
-        basepath = uncabspath(path)
+        basepath = long_path_support(path)
         if not allow_skip:
             # entry is a `os.DirEntry`
             def modpathrelative(entry):
@@ -427,11 +503,14 @@ def scandir_rec_simple(
     others: bool = False,
     rec: bool = True,
     follow_symlinks: bool = True,
+    prevent_loops: bool = True,
     errorfunc: Callable[[MyDirEntryT, Exception], None] = scandir_error_log_warning,
 ) -> Iterator[DirEntry]:
 
     entry = DirEntryStub(os.path.basename(path), path)
-    return _scandir_rec(entry, files, dirs, others, rec, follow_symlinks, errorfunc)
+    prevent_loops_set: Optional[Set[str]] = set() if prevent_loops else None
+
+    return _scandir_rec(entry, files, dirs, others, rec, follow_symlinks, prevent_loops_set, errorfunc)
 
 
 def scandir_ext(
@@ -454,9 +533,9 @@ def scandir_ext(
 def scandir_ext_2(path: str, extensions: Set[str], rec: bool = True) -> Iterator[Path]:
 
     if rec:
-        paths = Path(uncabspath(path)).rglob("*")
+        paths = Path(long_path_support(path)).rglob("*")
     else:
-        paths = Path(uncabspath(path)).glob("*")
+        paths = Path(long_path_support(path)).glob("*")
 
     for p in paths:
         if p.suffix.lower() in extensions:
@@ -489,7 +568,9 @@ def scandir_depth(path: str, depth: int = 0, onerror: Callable = scandir_error_l
     The order is arbitrary otherwise.
     """
 
-    entry = DirEntryStub(os.path.basename(path), uncabspath(path))  # for python 2 compat. and long filename support
+    entry = DirEntryStub(
+        os.path.basename(path), long_path_support(path)
+    )  # for python 2 compat. and long filename support
     return _scandir_depth(entry, depth, onerror)
 
 
@@ -886,7 +967,7 @@ def scandir_counts(
     if isinstance(path, PathLike):
         path = fspath(path)
 
-    entry = DirEntryStub(os.path.basename(path), uncabspath(path))
+    entry = DirEntryStub(os.path.basename(path), long_path_support(path))
     return _scandir_counts(entry, files, others, rec, total, onerror)
 
 
@@ -904,7 +985,12 @@ def shutil_onerror_remove_readonly(func, path, exc_info):
         raise
 
 
-def _rmtree(path: str, ignore_errors: bool = False, onerror: Optional[Callable[[Callable, str, Any], None]] = None):
+def _rmtree(
+    path: str,
+    ignore_errors: bool = False,
+    onerror: Optional[Callable[[Callable, str, Any], None]] = None,
+    follow_junctions: bool = False,
+) -> Iterator[None]:
 
     """Compared to `shutil.rmtree`, this removes files instantly,
     instead of collecting the whole directory contents first.
@@ -913,6 +999,12 @@ def _rmtree(path: str, ignore_errors: bool = False, onerror: Optional[Callable[[
     import sys
     from shutil import _rmtree_isdir
 
+    if not follow_junctions and sys.version_info < (3, 8):
+        raise ValueError("`follow_junctions=False` is unsupported for Python<3.8.")
+
+    if follow_junctions and sys.version_info >= (3, 8):
+        raise ValueError("`follow_junctions=True` is unsupported for Python>=3.8.")
+
     if ignore_errors:
 
         def onerror(*args):
@@ -929,7 +1021,7 @@ def _rmtree(path: str, ignore_errors: bool = False, onerror: Optional[Callable[[
                 fullname = entry.path
                 if _rmtree_isdir(entry):
                     try:
-                        if entry.is_symlink():
+                        if entry.is_symlink():  # not sure why this is necessary, copied from shutil._rmtree_unsafe
                             raise OSError("Cannot call _rmtree on a symbolic link")
                     except OSError:
                         onerror(os.path.islink, fullname, sys.exc_info())
