@@ -1,22 +1,17 @@
 from __future__ import generator_stop
 
 import logging
-from typing import TYPE_CHECKING
 
 import numpy as np
-from PIL import ImageFilter
+from PIL import Image, ImageFilter
 
 # from .numba import opjit
 from .numpy import rgb_to_hsi, rgb_to_ycbcr, unblock
 
 # fingerprinting aka perceptual hashing
 
-if TYPE_CHECKING:
-    from PIL import Image
 
-
-def phash_antijpeg(image):
-    # type: (Image, ) -> np.ndarray
+def phash_antijpeg(image: Image.Image) -> np.ndarray:
 
     """Source: An Anti-JPEG Compression Image Perceptual Hashing Algorithm
     `image` is a RGB pillow image.
@@ -25,7 +20,7 @@ def phash_antijpeg(image):
     raise NotImplementedError
 
 
-def hu_moments(channels):
+def hu_moments(channels: np.ndarray) -> np.ndarray:
 
     """Calculates all Hu invariant image moments for all channels separately.
     Input array must be of shape [width, height, channels]
@@ -90,7 +85,7 @@ def hu_moments(channels):
 
 
 # @opjit() rgb_to_hsi and rgb_to_ycbcr not supported by numba
-def phash_moments_array(arr):
+def phash_moments_array(arr: np.ndarray) -> np.ndarray:
     arr = arr / 255.0
 
     # convert colorspaces
@@ -100,8 +95,7 @@ def phash_moments_array(arr):
     return np.concatenate(hu_moments(channels).T)
 
 
-def phash_moments(image):
-    # type: (Image, ) -> np.ndarray
+def phash_moments(image: Image.Image) -> np.ndarray:
 
     """Source: Perceptual Hashing for Color Images Using Invariant Moments
     `image` is a RGB pillow image. Results should be compared with L^2-Norm of difference vector.
@@ -117,8 +111,7 @@ def phash_moments(image):
     return phash_moments_array(image)
 
 
-def phash_blockmean_array(arr, bits=256):
-    # type: (np.ndarray, int) -> np.ndarray
+def phash_blockmean_array(arr: np.ndarray, bits: int = 256) -> np.ndarray:
 
     """If bits is not a multiple of 8,
     the result will be zero padded from the right.
@@ -138,8 +131,7 @@ def phash_blockmean_array(arr, bits=256):
     return np.packbits(bools)
 
 
-def phash_blockmean(image, bits=256, x=256):
-    # type: (Image, int, int) -> bytes
+def phash_blockmean(image: Image.Image, bits: int = 256, x: int = 256) -> bytes:
 
     """Source: Block Mean Value Based Image Perceptual Hashing
     Method: 1
