@@ -1,21 +1,16 @@
 from __future__ import generator_stop
 
-from typing import TYPE_CHECKING
+from typing import Iterable, Iterator, Sequence, Tuple, TypeVar
 
-if TYPE_CHECKING:
-    from typing import Iterable, Iterator, Sequence, Tuple, TypeVar
-
-    T = TypeVar("T")
+T = TypeVar("T")
 
 
-def obj2tuple(obj):
-    # type: (T, ) -> Tuple[T]
+def obj2tuple(obj: T) -> Tuple[T]:
 
     return (obj,)
 
 
-def row_indices(n, square_length):
-    # type: (int, int) -> Iterable[int]
+def row_indices(n: int, square_length: int) -> Iterable[int]:
 
     """Returns the one-dimensional indices of all the cells belonging to the
     same row as index `n`.
@@ -25,8 +20,7 @@ def row_indices(n, square_length):
     return range(j * square_length, (j + 1) * square_length)
 
 
-def col_indices(n, square_length):
-    # type: (int, int) -> Iterable[int]
+def col_indices(n: int, square_length: int) -> Iterable[int]:
 
     """Returns the one-dimensional indices of all the cells belonging to the
     same column as index `n`.
@@ -36,8 +30,7 @@ def col_indices(n, square_length):
     return range(j, square_length * (square_length - 1) + j + 1, square_length)
 
 
-def subblock_indices(n, outer_square_length, inner_square_length):
-    # type: (int, int, int) -> Iterator[int]
+def subblock_indices(n: int, outer_square_length: int, inner_square_length: int) -> Iterator[int]:
 
     """Returns the one-dimensional indices of all the cells belonging to the
     same block as index `n`.
@@ -61,8 +54,7 @@ def subblock_indices(n, outer_square_length, inner_square_length):
             yield (y * i * j) + (i * iy) + (x * j) + (ix)
 
 
-def triangular_indices(n):
-    # type: (int, ) -> Iterator[Tuple[int, int]]
+def triangular_indices(n: int) -> Iterator[Tuple[int, int]]:
 
     """Returns all combinations of indices for a sequence of length `n` with duplicates and self-combinations.
     triangular_indices(4) -> (0, 1), (0, 2), (0, 3), (1, 2), (1, 3), (2, 3)
@@ -73,21 +65,18 @@ def triangular_indices(n):
             yield i, j
 
 
-def to_2d_index(n, width):
-    # type: (int, int) -> Tuple[int, int]
+def to_2d_index(n: int, width: int) -> Tuple[int, int]:
 
     return n // width, n % width
 
 
-def indices_2d(n, width):
-    # type: (int, int) -> Iterator[Tuple[int, int]]
+def indices_2d(n: int, width: int) -> Iterator[Tuple[int, int]]:
 
     for i in range(n):
         yield i // width, i % width
 
 
-def window_combinations_indices(size, window_size):
-    # type: (int, int) -> Iterator[Tuple[int, int]]
+def window_combinations_indices(size: int, window_size: int) -> Iterator[Tuple[int, int]]:
 
     """Yields all pairs of indices of a sequence of length `size` which are within a window
     of size `window_size`.
@@ -106,8 +95,7 @@ def window_combinations_indices(size, window_size):
             yield a, b
 
 
-def _combination_indices(start, sizes):
-    # type: (int, Sequence[int]) -> Iterator[Tuple[int, ...]]
+def _combination_indices(start: int, sizes: Sequence[int]) -> Iterator[Tuple[int, ...]]:
 
     """earlier (left) dimensions can never be higher than later (right) dimensions."""
 
@@ -119,7 +107,7 @@ def _combination_indices(start, sizes):
         yield from map(obj2tuple, range(start, sizes[0]))
 
 
-def combination_indices(*sizes):
+def combination_indices(*sizes: int) -> Iterator[Tuple[int, ...]]:
 
     """Given sequences of size a, b, c, ... yield the indices to index into each of them,
     so that all combinations of elements from the sequences are returned.
