@@ -519,13 +519,18 @@ def histogram_correlation(hist1: np.ndarray, hist2: np.ndarray) -> np.ndarray:
 
     """Input shape of `hist1` and `hist2`: [batch..., levels]. The correlation is calculated over `levels`
     and then batched over the remaining dimensions.
+    Similar to `cv2.compareHist(hist1, hist2, cv2.HISTCMP_CORREL)`.
     """
 
-    assert len(hist1.shape) >= 1 and hist1.shape == hist2.shape
+    if hist1.ndim < 1 or hist1.shape[-1] < 1 or hist1.shape != hist2.shape:
+        raise ValueError(f"Histogram shapes unsupported: {hist1.shape}, {hist2.shape}")
 
     h1norm = (hist1.T - np.mean(hist1, axis=-1)).T
     h2norm = (hist2.T - np.mean(hist2, axis=-1)).T
 
+    if np.count_nonzero(h1norm) == 0 or np.count_nonzero(h2norm) == 0:
+        raise ValueError("Both histograms are completely flat")
+
     num = np.sum(h1norm * h2norm, axis=-1)
     denom = np.sqrt(np.sum(h1norm**2, axis=-1) * np.sum(h2norm**2, axis=-1))
     return num / denom
@@ -770,3 +775,36 @@ def center_of_mass_2d(arr: np.ndarray, dtype=np.float32) -> np.ndarray:
     results = np.array([np.sum(arr * grid.astype(dtype), axis=(-1, -2)) / total for grid in grids], dtype=dtype).T
 
     return results
+
+
+def ceildiv(a: np.ndarray, b: np.ndarray) -> np.ndarray:
+    return -(a // -b)
+
+
+def image_grid(images: np.ndarray, nrow: int = 8, fill_value=(0, 0, 0)) -> np.ndarray:
+    """Creates a picture grid (left to right, top to bottom).
+    `images`: Input array of shape [n, height, widght, channel]
+    `nrow`: Number of images per row
+    `fill_value`: Pad empty space with pixels of shape [channel]
+    """
+
+    if not images.ndim == 4:
+        raise ValueError("Input shape must be [n, height, width, channel]")
+
+    h, w = images.shape[1:3]
+    nbatch = images.shape[0]
+    channels = images.shape[3]
+    rows = ceildiv(nbatch, nrow)
+    cols = min(nbatch, nrow)
+
+    if channels != len(fill_value):
+        raise ValueError("fill_value must match number of channels")
+
+    out = np.full((h * rows, w * cols, channels), fill_value, dtype=images.dtype)
+
+    for i in range(images.shape[0]):
+        row = i // cols
+        col = i % cols
+        out[h * row : h * (row + 1), w * col : w * (col + 1), :] = images[i]
+
+    return out
