@@ -1,7 +1,6 @@
 from __future__ import generator_stop
 
 
-def _filemanager_cmd_mac(path):
-    # type: (str, ) -> str
+def _filemanager_cmd_mac(path: str) -> str:
 
     return f'open -R "{path}"'
