@@ -9,8 +9,7 @@ class SegmentTree:
 
     t: List[Optional[int]]
 
-    def __init__(self, arr, func, initializer):
-        # type: (List[int], Callable[[int, int], int], int) -> None
+    def __init__(self, arr: List[int], func: Callable[[int, int], int], initializer: int) -> None:
 
         self.n = len(arr)
         self.func = func
@@ -18,16 +17,14 @@ class SegmentTree:
 
         self.t = [None] * self.n + arr  # type
 
-    def build(self):
-        # type: () -> None
+    def build(self) -> None:
 
         i = self.n - 1
         while i > 0:
             self.t[i] = self.func(self.t[i << 1], self.t[i << 1 | 1])
             i -= 1
 
-    def modify(self, p, value):
-        # type: (int, int) -> None
+    def modify(self, p: int, value: int) -> None:
 
         p += self.n
         self.t[p] = value
@@ -37,8 +34,7 @@ class SegmentTree:
             p >>= 1
             self.t[p] = val
 
-    def query(self, left, right):
-        # type: (int, int) -> int
+    def query(self, left: int, right: int) -> int:
 
         if left >= right or not 0 <= left <= self.n or not 0 <= right <= self.n:
             raise ValueError(f"Interval [{left}, {right}) out of range")
