@@ -2,21 +2,17 @@ from __future__ import generator_stop
 
 from math import pow
 from random import sample
-from typing import TYPE_CHECKING
+from typing import Collection
 
 from .compat.math import prod
 from .math import reciprocal
 
-if TYPE_CHECKING:
-    from collections.abc import Collection
-
 
 def sample_range(total, num):
     return sample(range(total), min(num, total))
 
 
-def arithmetic_mean(col):
-    # type: (Collection, ) -> float
+def arithmetic_mean(col: Collection) -> float:
 
     """Arithmetic mean of `col`."""
 
@@ -26,16 +22,14 @@ def arithmetic_mean(col):
 mean = arithmetic_mean
 
 
-def harmonic_mean(col):
-    # type: (Collection, ) -> float
+def harmonic_mean(col: Collection) -> float:
 
     """Harmonic mean of `col`."""
 
     return len(col) / sum(map(reciprocal, col))
 
 
-def geometric_mean(col):
-    # type: (Collection, ) -> float
+def geometric_mean(col: Collection) -> float:
 
     """Geometric mean of `col`."""
 
