@@ -6,7 +6,6 @@ from typing import List
 re_paragraphs = re.compile(r"((?:[^\n][\n]?)+)")
 
 
-def split_paragraphs(text):
-    # type: (str, ) -> List[str]
+def split_paragraphs(text: str) -> List[str]:
 
     return re_paragraphs.findall(text)
