@@ -1,9 +1,12 @@
 from __future__ import generator_stop
 
-from typing import TYPE_CHECKING
+from typing import Union
 
 from cryptography.hazmat.backends import default_backend
-from cryptography.hazmat.primitives.asymmetric.rsa import generate_private_key
+from cryptography.hazmat.primitives.asymmetric.dh import DHPrivateKey
+from cryptography.hazmat.primitives.asymmetric.dsa import DSAPrivateKey
+from cryptography.hazmat.primitives.asymmetric.ec import EllipticCurvePrivateKey
+from cryptography.hazmat.primitives.asymmetric.rsa import RSAPrivateKey, generate_private_key
 from cryptography.hazmat.primitives.serialization import (
     Encoding,
     NoEncryption,
@@ -13,36 +16,25 @@ from cryptography.hazmat.primitives.serialization import (
     load_pem_private_key,
 )
 from OpenSSL import crypto  # pyOpenSSL
+from OpenSSL.crypto import X509
 
 from .exceptions import assert_choice
 
-if TYPE_CHECKING:
-    from typing import Union
-
-    from cryptography.hazmat.primitives.asymmetric.dh import DHPrivateKey
-    from cryptography.hazmat.primitives.asymmetric.dsa import DSAPrivateKey
-    from cryptography.hazmat.primitives.asymmetric.ec import EllipticCurvePrivateKey
-    from cryptography.hazmat.primitives.asymmetric.rsa import RSAPrivateKey
-    from OpenSSL.crypto import X509
-
-    PrivateKey = Union[RSAPrivateKey, DSAPrivateKey, DHPrivateKey, EllipticCurvePrivateKey]
+PrivateKey = Union[RSAPrivateKey, DSAPrivateKey, DHPrivateKey, EllipticCurvePrivateKey]
 
 
-def load_certificate_file(filename):
-    # type: (str, ) -> X509
+def load_certificate_file(filename: str) -> X509:
 
     with open(filename, "rb") as fr:
         return crypto.load_certificate(crypto.FILETYPE_PEM, fr.read())
 
 
-def get_pubkey_from_x509(x509):
-    # type: (X509, ) -> bytes
+def get_pubkey_from_x509(x509: X509) -> bytes:
 
     return crypto.dump_privatekey(crypto.FILETYPE_ASN1, x509.get_pubkey())
 
 
-def load_keyfile(filename, encoding="PEM"):
-    # type: (str, str) -> PrivateKey
+def load_keyfile(filename: str, encoding: str = "PEM") -> PrivateKey:
 
     try:
         load_func = {
@@ -58,8 +50,9 @@ def load_keyfile(filename, encoding="PEM"):
         return load_func(fr.read(), password, backend)
 
 
-def generate_rsa_keyfile_pair(priv_key, pub_key, key_size=4096, encoding="PEM", format="modern"):
-    # type: (str, str, int, str, str) -> RSAPrivateKey
+def generate_rsa_keyfile_pair(
+    priv_key: str, pub_key: str, key_size: int = 4096, encoding: str = "PEM", format: str = "modern"
+) -> RSAPrivateKey:
 
     """
     encoding: "PEM" -> ASN.1 encoding, "DER" -> base64 PEM
