@@ -1,22 +1,17 @@
 from __future__ import generator_stop
 
-from typing import TYPE_CHECKING
+from typing import Any
 
 import toml
 
-if TYPE_CHECKING:
-    from typing import Any
 
-
-def read_toml(path):
-    # type: (str, ) -> Any
+def read_toml(path: str) -> Any:
 
     with open(path, encoding="utf-8") as fr:
         return toml.load(fr)
 
 
-def write_toml(obj, path):
-    # type: (Any, str) -> None
+def write_toml(obj: Any, path: str) -> None:
 
     with open(path, "w", encoding="utf-8") as fw:
         toml.dump(obj, fw)
