@@ -4,15 +4,17 @@ from typing import Any
 
 from ruamel.yaml import YAML
 
+from ._files import PathType
 
-def read_yaml(path: str) -> Any:
+
+def read_yaml(path: PathType) -> Any:
 
     with open(path, encoding="utf-8") as fr:
         yaml = YAML(typ="safe")
         return yaml.load(fr)
 
 
-def write_yaml(obj: str, path: Any) -> None:
+def write_yaml(obj: PathType, path: Any) -> None:
 
     with open(path, "w", encoding="utf-8") as fw:
         yaml = YAML(typ="safe")
